<?php
/**
 * The base configurations of the WordPress.
 *
 * This file has the following configurations: MySQL settings, Table Prefix,
 * Secret Keys, WordPress Language, and ABSPATH. You can find more information
 * by visiting {@link http://codex.wordpress.org/Editing_wp-config.php Editing
 * wp-config.php} Codex page. You can get the MySQL settings from your web host.
 *
 * This file is used by the wp-config.php creation script during the
 * installation. You don't have to use the web site, you can just copy this file
 * to "wp-config.php" and fill in the values.
 *
 * @package WordPress
 */

// NOTE: File lives outside WordPress core and the config files with the credentials
// also live outside webroot for additional security.

define( 'APP_ROOT', dirname( __DIR__ ) );

define( 'APP_ENV', getenv( 'APPLICATION_ENV' ) );

/** Require Composer Autoload file */
require APP_ROOT . '/vendor/autoload.php';

$dotenv = new Dotenv\Dotenv( APP_ROOT . '/' );
$dotenv->load();

/** Require environment specific configuration */
if (file_exists( APP_ROOT . '/config/env/local/local.php' )) {
    require_once APP_ROOT . '/config/env/local/local.php';
} elseif (defined( 'APP_ENV' )) {
    require_once APP_ROOT . '/config/env/' . APP_ENV . '.php';
} else {
    // modify the config file based on environment
    if (( strpos(
              $_SERVER['SERVER_ADDR'],
              '127.0.0.1'
          ) !== false ) || ( strpos(
                                 $_SERVER['SERVER_ADDR'],
                                 '172.20.10.6'
                             ) !== false )
    ) {
        $config_file = 'wp-config-local.php';
        define( 'WP_LOCAL_DEV', true );
        define( 'WP_DEBUG', true );
    } else {

// Define Environments - may be a string or array of options for an environment
        $environments = array(
            'local'       => array( '.local', 'local.' ),
            'development' => 'dev.',
            'staging'     => array( 'staging.', '.catlab.co.uk' ),
            'preview'     => 'preview.',
        );

// Get Server name
        $server_name = $_SERVER['SERVER_NAME'];

        foreach ($environments AS $key => $env) {

            if (is_array( $env )) {
                foreach ($env as $option) {
                    if (stristr( $server_name, $option )) {
                        define( 'ENVIRONMENT', $key );
                        break 2;
                    }
                }
            } else {
                if (strstr( $server_name, $env )) {
                    define( 'ENVIRONMENT', $key );
                    break;
                }
            }
        }

// If no environment is set default to production
        if ( ! defined( 'ENVIRONMENT' )) {
            define( 'ENVIRONMENT', 'production' );
        }

// Define different DB connection details depending on environment
        switch (ENVIRONMENT) {
            case 'local':
                $config_file = 'wp-config-local.php';
                define( 'WP_LOCAL_DEV', true );
                break;
            case 'development':
                $config_file = 'wp-config-dev.php';
                define( 'WP_DEV', true );
                break;
            case 'staging':
                $config_file = 'wp-config-staging.php';
                define( 'WP_STAGING', true );
                break;
            case 'preview':
                $config_file = 'wp-config-preview.php';
                define( 'WP_PREVIEW', true );
                break;
            case 'production':
                $config_file = 'wp-config-production.php';
                define( 'WP_PRODUCTION', true );
                break;
        }
    }

    $path = __DIR__ . '/';
    require_once $path . $config_file;
}

// ** MySQL settings - You can get this info from your web host ** //
// If database isn't defined then it will be defined here.
// Put the details for your production environment in here.

/** The name of the database for WordPress */
if ( ! defined( 'DB_NAME' )) {
    define( 'DB_NAME', 'database_name_here' );
}

/** MySQL database username */
if ( ! defined( 'DB_USER' )) {
    define( 'DB_USER', 'username_here' );
}

/** MySQL database password */
if ( ! defined( 'DB_PASSWORD' )) {
    define( 'DB_PASSWORD', 'password_here' );
}

/** MySQL hostname */
if ( ! defined( 'DB_HOST' )) {
    define( 'DB_HOST', 'localhost' );
}

/** Database Charset to use in creating database tables. */
if ( ! defined( 'DB_CHARSET' )) {
    define( 'DB_CHARSET', 'utf8' );
}

/** The Database Collate type. Don't change this if in doubt. */
if ( ! defined( 'DB_COLLATE' )) {
    define( 'DB_COLLATE', '' );
}

/**#@+
 * Authentication Unique Keys and Salts.
 *
 * Change these to different unique phrases!
 * You can generate these using the {@link https://api.wordpress.org/secret-key/1.1/salt/ WordPress.org secret-key service}
 * You can change these at any point in time to invalidate all existing cookies. This will force all users to have to log in again.
 *
 * @since 2.6.0
 */
if ( ! defined( 'AUTH_KEY' )) {
    define( 'AUTH_KEY', 'put your unique phrase here' );
}

if ( ! defined( 'SECURE_AUTH_KEY' )) {
    define( 'SECURE_AUTH_KEY', 'put your unique phrase here' );
}

if ( ! defined( 'LOGGED_IN_KEY' )) {
    define( 'LOGGED_IN_KEY', 'put your unique phrase here' );
}

if ( ! defined( 'NONCE_KEY' )) {
    define( 'NONCE_KEY', 'put your unique phrase here' );
}

if ( ! defined( 'AUTH_SALT' )) {
    define( 'AUTH_SALT', 'put your unique phrase here' );
}

if ( ! defined( 'SECURE_AUTH_SALT' )) {
    define( 'SECURE_AUTH_SALT', 'put your unique phrase here' );
}

if ( ! defined( 'LOGGED_IN_SALT' )) {
    define( 'LOGGED_IN_SALT', 'put your unique phrase here' );
}

if ( ! defined( 'NONCE_SALT' )) {
    define( 'NONCE_SALT', 'put your unique phrase here' );
}

/**#@-*/

/**
 * WordPress Database Table prefix.
 *
 * You can have multiple installations in one database if you give each a unique
 * prefix. Only numbers, letters, and underscores please!
 */
if ( ! isset( $table_prefix )) {
    $table_prefix = 'wp_';
}

/**
 * WordPress Localized Language, defaults to English.
 *
 * Change this to localize WordPress. A corresponding MO file for the chosen
 * language must be installed to wp-content/languages. For example, install
 * de_DE.mo to wp-content/languages and set WPLANG to 'de_DE' to enable German
 * language support.
 */
if ( ! defined( 'WPLANG' )) {
    define( 'WPLANG', '' );
}

/**
 * For developers: WordPress debugging mode.
 *
 * Change this to true to enable the display of notices during development.
 * It is strongly recommended that plugin and theme developers use WP_DEBUG
 * in their development environments.
 */
if ( ! defined( 'WP_DEBUG' )) {
    define( 'WP_DEBUG', false );
}

/* That's all, stop editing! Happy blogging. */

/** Absolute path to the WordPress directory. */
if ( ! defined( 'ABSPATH' )) {
    define( 'ABSPATH', APP_ROOT . '/public_html/wp/' );
}

